﻿namespace TestProject;

/// <summary>
/// 메인 페이지
/// </summary>
public partial class MainPage : ContentPage
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
    ////////////////////////////////////////////////////////////////////////////////////////// Public

    #region 생성자 - MainPage()

    /// <summary>
    /// 생성자
    /// </summary>
    public MainPage()
    {
        InitializeComponent();

        this.getbutton.Clicked += getbutton_Clicked;
    }

    #endregion

    //////////////////////////////////////////////////////////////////////////////////////////////////// Method
    ////////////////////////////////////////////////////////////////////////////////////////// Private

    #region GPS 위치 구하기 버튼 클릭시 처리하기 - getbutton_Clicked(sender, e)

    /// <summary>
    /// GPS 위치 구하기 버튼 클릭시 처리하기
    /// </summary>
    /// <param name="sender">이벤트 발생자</param>
    /// <param name="e">이벤트 인자</param>
    private async void getbutton_Clicked(object sender, EventArgs e)
    {
        try
        {
            GeolocationRequest request = new GeolocationRequest(GeolocationAccuracy.Medium);

            Location location = await Geolocation.Default.GetLocationAsync(request);

            if(location != null)
            {
                this.messageLabel.Text = $"위도 : {location.Latitude}\n경도 : {location.Longitude}\n고도 : {location.Altitude}";
            }
        }
        catch(FeatureNotSupportedException)
        {
            await DisplayAlert("ERROR", "지원되지 않은 기능입니다.", "확인");
        }
        catch(FeatureNotEnabledException)
        {
            await DisplayAlert("ERROR", "비활성된 기능입니다.", "확인");
        }
        catch(PermissionException)
        {
            await DisplayAlert("ERROR", "권한이 설정되지 않았습니다.", "확인");
        }
        catch(Exception)
        {
            await DisplayAlert("ERROR", "실행시 에러가 발생했습니다.", "확인");
        }
    }

    #endregion
}